import { ReactNode } from 'react';
import { ListOnItemsRenderedProps } from 'react-window';
type OnItemsRendered = (props: ListOnItemsRenderedProps) => unknown;
type Direction = 'start' | 'end';
type Props = {
    /** Return whether an item at the index has been loaded. */
    isItemLoaded: (index: number) => boolean;
    /**
     * Callback to load more items.
     * Receives a parameter `'start'` or `'end'` to load items at the start or end.
     */
    loadMoreItems: (direction: Direction) => Promise<unknown> | unknown;
    /**
     * Callback to be called when items have been rendered.
     * This prop is optional.
     */
    onItemsRendered?: OnItemsRendered;
    /** Returns the number of items. Can be arbitrary large if the total size is unknown. */
    itemCount: number;
    /**
     * Threshold value to load more items on items rendered.
     * When 1st ~ *threshold*th first item at either end is visible, `loadMoreItems` will be called.
     * Setting the value `0` or smaller might disable calling `loadMoreItems` on items rendered.
     */
    threshold: number;
    /**
     * offset value (in `px`) for smooth infinite scrolling.
     * Recommends value equal to minimum length of items or higher.
    */
    scrollOffset: number;
    /** children that receives `onItemsRendered` props and returns `ReactNode`. */
    children: ({ onItemsRendered }: {
        onItemsRendered: OnItemsRendered;
    }) => ReactNode;
    /** `ref` to the outer continer element. Passing the HTML element directly is also permitted. */
    outerRef: React.RefObject<HTMLElement> | HTMLElement;
    /** *Actual* data that needs to be virtually scrolled. */
    data: unknown[];
    /** Layout of the virtual list. Default is `'vertical'`. */
    layout?: 'vertical' | 'horizontal';
};
declare const InfiniteScroll: ({ isItemLoaded, loadMoreItems, onItemsRendered, itemCount, threshold, scrollOffset, children, outerRef, data, layout, }: Props) => JSX.Element;
export default InfiniteScroll;
